@@ -3,8 +3,9 @@
 
 testLineNo()
 {
-  # this assert will have line numbers included (e.g. "ASSERT:[123] ...")
-  echo "ae: ${_ASSERT_EQUALS_}"
+  # this assert will have line numbers included (e.g. "ASSERT:[123] ...") if
+  # they are supported.
+  echo "_ASSERT_EQUALS_ macro value: ${_ASSERT_EQUALS_}"
   ${_ASSERT_EQUALS_} 'not equal' 1 2
 
   # this assert will not have line numbers included (e.g. "ASSERT: ...")
@@ -12,4 +13,4 @@ testLineNo()
 }
 
 # load shunit2
-. ../src/shell/shunit2
+. ../src/shunit2
